use cli::Cli;
use cuddle_state::Cuddle;

mod cli;
mod cuddle_state;
mod plan;
mod project;
mod schema_validator;
mod state;

#[tokio::main]
async fn main() -> anyhow::Result<()> {
    dotenv::dotenv().ok();
    tracing_subscriber::fmt::init();

    let cuddle = Cuddle::default()
        .prepare_project()
        .await?
        .prepare_plan()
        .await?
        .build_state()
        .await?;

    Cli::new(cuddle).setup().await?.execute().await?;

    Ok(())
}
