use std::path::{Path, PathBuf};

use anyhow::anyhow;
use cuddle_value::Value;
use toml::Table;

use crate::project::CUDDLE_PROJECT_FILE;

#[derive(Clone)]
pub struct Project {
    pub value: Value,
    pub root: PathBuf,
}

impl Project {
    pub fn new(value: Value, root: &Path) -> Self {
        Self {
            value,
            root: root.to_path_buf(),
        }
    }

    pub fn from_file(content: &str, root: &Path) -> anyhow::Result<Self> {
        let table: Table = toml::from_str(content)?;

        let project = table
            .get("project")
            .ok_or(anyhow!("cuddle.toml doesn't provide a [project] table"))?;

        let value: Value = project.into();
        let value = Value::Map([("project".to_string(), value)].into());

        Ok(Self::new(value, root))
    }

    pub async fn from_path(path: &Path) -> anyhow::Result<Self> {
        let cuddle_file = path.join(CUDDLE_PROJECT_FILE);

        if !cuddle_file.exists() {
            anyhow::bail!("no cuddle.toml project file found");
        }

        let cuddle_project_file = tokio::fs::read_to_string(cuddle_file).await?;

        Self::from_file(&cuddle_project_file, path)
    }
}
